@@ -54,14 +54,17 @@ import org.jgraph.event.GraphModelEvent;
 import org.jgraph.event.GraphModelListener;
 import org.jgraph.event.GraphSelectionEvent;
 import org.jgraph.event.GraphSelectionListener;
+import org.jgraph.graph.AbstractCellView;
 import org.jgraph.graph.BasicMarqueeHandler;
 import org.jgraph.graph.CellHandle;
 import org.jgraph.graph.CellView;
 import org.jgraph.graph.DefaultCellViewFactory;
 import org.jgraph.graph.DefaultEdge;
 import org.jgraph.graph.DefaultGraphCell;
+import org.jgraph.graph.DefaultGraphCellEditor;
 import org.jgraph.graph.DefaultGraphModel;
 import org.jgraph.graph.Edge;
+import org.jgraph.graph.EdgeRenderer;
 import org.jgraph.graph.EdgeView;
 import org.jgraph.graph.GraphConstants;
 import org.jgraph.graph.GraphContext;
@@ -69,7 +72,10 @@ import org.jgraph.graph.GraphLayoutCache;
 import org.jgraph.graph.GraphModel;
 import org.jgraph.graph.GraphUndoManager;
 import org.jgraph.graph.Port;
+import org.jgraph.graph.PortRenderer;
 import org.jgraph.graph.PortView;
+import org.jgraph.graph.VertexRenderer;
+import org.jgraph.graph.VertexView;
 
 public class GraphEd extends JApplet implements GraphSelectionListener,
 		KeyListener {
@@ -184,6 +190,14 @@ public class GraphEd extends JApplet implements GraphSelectionListener,
 		installListeners(graph);
 	}
 
+	public void destroy() {
+		super.destroy();
+		PortView.renderer = new PortRenderer();
+		EdgeView.renderer = new EdgeRenderer();
+		AbstractCellView.cellEditor = new DefaultGraphCellEditor();
+		VertexView.renderer = new VertexRenderer();
+	}
+	
 	// Hook for subclassers
 	protected void populateContentPane() {
 		// Use Border Layout
