@@ -59,6 +59,7 @@ import org.jgraph.graph.GraphModel;
 import org.jgraph.graph.GraphSelectionModel;
 import org.jgraph.graph.PortView;
 import org.jgraph.plaf.GraphUI;
+import org.jgraph.plaf.basic.BasicGraphUI;
 
 /**
  * A control that displays a network of related objects using the well-known
@@ -182,7 +183,7 @@ public class JGraph
 		// org.jgraph.plaf.basic.TransferHandler.JAdapterComponent
 		implements Scrollable, Accessible, Serializable {
 
-	public static final String VERSION = "JGraph (v5.10.1.2)";
+	public static final String VERSION = "JGraph (v5.10.1.5)";
 
 	public static final int DOT_GRID_MODE = 0;
 
@@ -2120,6 +2121,14 @@ public class JGraph
 				setOffscreenValid(false);
 			}
 		}
+		if (!isOffscreenValid()) {
+			offgraphics.setColor(getBackground());
+			offgraphics.setPaintMode();
+			offgraphics.fillRect(0, 0, (int) graphBounds.getWidth(), (int) graphBounds
+					.getHeight());
+			((BasicGraphUI)getUI()).drawGraph(offgraphics, null);
+			offscreenValid = true;
+		}
 		return offgraphics;
 	}
 
