@@ -79,12 +79,12 @@ public class DefaultGraphModel extends UndoableEditSupport implements
 	/**
 	 * A collection of unexecuted updates on this model
 	 */
-	protected Collection currentUpdate = new ArrayList();
+//	protected Collection currentUpdate = new ArrayList();
 
 	/**
 	 * Whether or not an update is in the process of being dispatched
 	 */
-	private transient boolean isDispatching = false;
+//	private transient boolean isDispatching = false;
 
 	/**
 	 * Constructs a model that is not an attribute store.
@@ -556,10 +556,10 @@ public class DefaultGraphModel extends UndoableEditSupport implements
 	 * @see com.jgraph.model.GraphModel#execute(com.jgraph.model.DefaultGraphModel.Change)
 	 */
 	public synchronized void execute(ExecutableChange change) {
-		change.execute();
-		beginUpdate();
-		currentUpdate.add(change);
-		endUpdate();
+//		change.execute();
+//		beginUpdate();
+//		currentUpdate.add(change);
+//		endUpdate();
 	}
 
 	/*
@@ -568,7 +568,8 @@ public class DefaultGraphModel extends UndoableEditSupport implements
 	 * @see com.jgraph.model.GraphModel#getUpdateLevel()
 	 */
 	public int getUpdateLevel() {
-		return updateLevel;
+		return super.getUpdateLevel();
+		//return updateLevel;
 	}
 
 	/*
@@ -577,7 +578,8 @@ public class DefaultGraphModel extends UndoableEditSupport implements
 	 * @see javax.swing.undo.UndoableEditSupport#beginUpdate()
 	 */
 	public void beginUpdate() {
-		updateLevel++;
+		super.beginUpdate();
+		//updateLevel++;
 	}
 
 	/*
@@ -586,6 +588,7 @@ public class DefaultGraphModel extends UndoableEditSupport implements
 	 * @see com.jgraph.model.GraphModel#endUpdate()
 	 */
 	public void endUpdate() {
+		super.endUpdate();
 //		boolean dispatch = false;
 //		synchronized (this) {
 //			updateLevel--;
