@@ -464,13 +464,13 @@ public class EdgeRenderer extends JComponent implements CellViewRenderer,
 		
 		double length = 0;
 		double[] segments = new double[pointCount];
-		Point2D pt = edge.getPointLocation(0);
+		Point2D pt = edge.getPoint(0);
 		
 		if (pt != null)
 		{
 			for (int i = 1; i < pointCount; i++)
 			{
-				Point2D tmp = edge.getPointLocation(i);
+				Point2D tmp = edge.getPoint(i);
 				
 				if (tmp != null)
 				{
@@ -502,8 +502,8 @@ public class EdgeRenderer extends JComponent implements CellViewRenderer,
 
 			double factor = (dist - length) / segment;
 			
-			Point2D p0 = edge.getPointLocation(index - 1);
-			Point2D pe = edge.getPointLocation(index);
+			Point2D p0 = edge.getPoint(index - 1);
+			Point2D pe = edge.getPoint(index);
 
 			if (p0 != null && pe != null)
 			{
