@@ -2221,13 +2221,12 @@ public class GraphLayoutCache implements CellMapper, Serializable {
 			if (view != null) {
 				CellView parent = getMapping(model.getParent(cell), false);
 				if (parent != null) {
-					if (parent instanceof VertexView) {
-
+					if (DefaultGraphModel.isVertex(model, parent)) 
+					{
 						// Computes the offset of the parent group
-						VertexView vertex = (VertexView) parent;
 						Rectangle2D src = GraphConstants.getBounds(parent
 								.getAllAttributes());
-						Rectangle2D rect = vertex.getBounds();
+						Rectangle2D rect = parent.getBounds();
 						double dx = src.getX() - rect.getX();
 						double dy = src.getY() - rect.getY();
 
