@@ -928,21 +928,6 @@ public class BasicGraphUI extends GraphUI implements Serializable {
 				int volatileContentsLostCount = 0;
 				do {
 					offGraphics = graph.getOffgraphics();
-					if (!graph.isOffscreenValid()) {
-						Rectangle2D offGraphicsClip = (Rectangle2D) offGraphics
-								.getClipBounds();
-						if (offGraphicsClip != null) {
-							offGraphicsClip = (Rectangle2D) offGraphicsClip
-									.clone();
-						}
-						if (offGraphicsClip != null && clipBounds != null) {
-							Rectangle2D.union(offGraphicsClip, clipBounds,
-									offGraphicsClip);
-						}
-						renderOffscreen(offGraphics,
-								(offGraphicsClip == null) ? clipBounds
-										: offGraphicsClip);
-					}
 					volatileContentsLostCount++;
 					if (volatileContentsLostCount > 10) {
 						// Assume a problem with the volatile buffering
@@ -950,20 +935,6 @@ public class BasicGraphUI extends GraphUI implements Serializable {
 						graph.setVolatileOffscreen(false);
 					}
 				} while (((VolatileImage) offscreen).contentsLost());
-			} else if (offscreen instanceof BufferedImage) {
-				if (!graph.isOffscreenValid()) {
-					Rectangle2D offGraphicsClip = offGraphics.getClipBounds();
-					if (offGraphicsClip != null) {
-						offGraphicsClip = (Rectangle2D) offGraphicsClip.clone();
-					}
-					if (offGraphicsClip != null && clipBounds != null) {
-						Rectangle2D.union(offGraphicsClip, clipBounds,
-								offGraphicsClip);
-					}
-					renderOffscreen(offGraphics,
-							(offGraphicsClip == null) ? clipBounds
-									: offGraphicsClip);
-				}
 			}
 			graph.setOffscreenValid(true);
 			g.drawImage(graph.getOffscreen(), 0, 0, graph);
@@ -1002,7 +973,7 @@ public class BasicGraphUI extends GraphUI implements Serializable {
 	 * @param clipBounds
 	 *            the bounds within graph cells must intersect to be redrawn
 	 */
-	protected void drawGraph(Graphics g, Rectangle2D clipBounds) {
+	public void drawGraph(Graphics g, Rectangle2D clipBounds) {
 		Rectangle2D realClipBounds = null;
 		if (clipBounds != null) {
 			Rectangle2D paintBounds = new Rectangle2D.Double(clipBounds.getX(),
@@ -2472,9 +2443,6 @@ public class BasicGraphUI extends GraphUI implements Serializable {
 			}
 			try {
 				offgraphics = graph.getOffgraphics();
-				if (!graph.isOffscreenValid()) {
-					graph.getUI().paint(offgraphics, graph);
-				}
 			} catch (Exception e) {
 				offgraphics = null;
 			} catch (Error e) {
@@ -2526,14 +2494,8 @@ public class BasicGraphUI extends GraphUI implements Serializable {
 							dy = constrainedPosition.getY();
 						}
 						double scale = graph.getScale();
-						dx = (int) (dx / scale);
-						// we don't want to round. The best thing is to get just
-						// the integer part.
-						// That way, the view won't "run away" from the mouse.
-						// It may lag behind
-						// a mouse pointer occasionally, but will be catching
-						// up.
-						dy = (int) (dy / scale);
+						dx = dx / scale;
+						dy = dy / scale;
 						// Start Drag and Drop
 						if (graph.isDragEnabled() && !isDragging)
 							startDragging(event);
@@ -2793,8 +2755,16 @@ public class BasicGraphUI extends GraphUI implements Serializable {
 						activeHandle = null;
 					} else if (isMoving && !event.getPoint().equals(start)) {
 						if (cachedBounds != null) {
-							double dx = event.getX() - start.getX();
-							double dy = event.getY() - start.getY();
+							
+							Point ep = event.getPoint();
+							Point2D point = new Point2D.Double(ep.getX()
+									- _mouseToViewDelta_x, ep.getY()
+									- _mouseToViewDelta_y);
+							Point2D snapCurrent = graph.snap(point);
+							
+							double dx = snapCurrent.getX() - start.getX();
+							double dy = snapCurrent.getY() - start.getY();
+							
 							Point2D tmp = graph.fromScreen(new Point2D.Double(
 									dx, dy));
 							GraphLayoutCache.translateViews(views, tmp.getX(),
